# EGene

Tool for applying, visualizing, and training neural networks using 
a genetic algorithm

# Features


+ Training a population with any set of training data or loss function
+ Total control over the size and shape of the neural network
+ Multiprocessing for parallel training
+ Viewing the neural network
+ Pygame surfaces integration
+ Easy use

# Documentation
+ [DOCS.md](https://github.com/Elan456/EGene/blob/e59734f9f85decdf2c03e574b3802412fb660493/DOCS.md)

Installation
------------

Install EGene by running:

    pip install egene

Contribute
----------
Source code:
- https://github.com/Elan456/PyGene


License
-------
MIT
